==> zwap_design_system-0.1.28.tar.gz: lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:taastrap/taastrap.dart';
import 'package:zwap_utils/zwap_utils.dart';

import 'atoms/atoms.dart';
import 'molecules/molecules.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        debugShowCheckedModeBanner: false,
        title: 'Zwap | Build connections that matter',
        theme: zwapThemeData,
        home: LayoutBuilder(builder: (context, size) {
          Generic deviceType = Generic(maxWith: size.maxWidth.toInt());
          if (Utils.getIt.isRegistered<Generic>()) {
            Utils.getIt.unregister<Generic>();
          }
          Utils.getIt.registerSingleton<Generic>(deviceType);
          return MyHomePage(title: "");
        })
    );
  }
}

class MyHomePage extends StatefulWidget {

  MyHomePage({Key? key, required this.title}) : super(key: key);

  // This widget is the home page of your application. It is stateful, meaning
  // that it has a State object (defined below) that contains fields that affect
  // how it looks.

  // This class is the configuration for the state. It holds the values (in this
  // case the title) provided by the parent (in this case the App widget) and
  // used by the build method of the State. Fields in a Widget subclass are
  // always marked "final".

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {

  @override
  Widget build(BuildContext context) {
    // This method is rerun every time setState is called, for instance as done
    // by the _incrementCounter method above.
    //
    // The Flutter framework has been optimized to make rerunning build methods
    // fast, so that you can just rebuild anything that needs updating rather
    // than having to individually change instances of widgets.
    ResponsiveWidget element = ZwapOpenToTag(
        openToTagText: "CIAO",
        tagIcon: Icons.refresh,
        callBackClick: (String element) => {}
    );
    element.getSize("CIAO");
    return Scaffold(
        body: Column(
          children: [
            element
          ],
        )
    );
  }
}

==> zwap_design_system-0.1.34.tar.gz: lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:taastrap/taastrap.dart';
import 'package:zwap_utils/zwap_utils.dart';

import 'atoms/atoms.dart';
import 'molecules/molecules.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        debugShowCheckedModeBanner: false,
        title: 'Zwap | Build connections that matter',
        theme: zwapThemeData,
        home: LayoutBuilder(builder: (context, size) {
          Generic deviceType = Generic(maxWith: size.maxWidth.toInt());
          if (Utils.getIt.isRegistered<Generic>()) {
            Utils.getIt.unregister<Generic>();
          }
          Utils.getIt.registerSingleton<Generic>(deviceType);
          return MyHomePage(title: "");
        })
    );
  }
}

class MyHomePage extends StatefulWidget {

  MyHomePage({Key? key, required this.title}) : super(key: key);

  // This widget is the home page of your application. It is stateful, meaning
  // that it has a State object (defined below) that contains fields that affect
  // how it looks.

  // This class is the configuration for the state. It holds the values (in this
  // case the title) provided by the parent (in this case the App widget) and
  // used by the build method of the State. Fields in a Widget subclass are
  // always marked "final".

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {

  @override
  Widget build(BuildContext context) {
    // This method is rerun every time setState is called, for instance as done
    // by the _incrementCounter method above.
    //
    // The Flutter framework has been optimized to make rerunning build methods
    // fast, so that you can just rebuild anything that needs updating rather
    // than having to individually change instances of widgets.
    ResponsiveWidget element = ZwapStatusBadge(statusText: "CIAO", statusIcon: Icons.refresh, statusIconColor: ZwapColors.getRandomColor(), callBackClick: (String key) {});
    print(element.getSize());
    return Scaffold(
        body: Column(
          children: [
            element
          ],
        )
    );
  }
}
